/*
 * Copyright (C) 2018 Rerrah
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SLIDER_STYLE_HPP
#define SLIDER_STYLE_HPP

#include <QProxyStyle>

class SliderStyle : public QProxyStyle
{
private:
	SliderStyle(QStyle *style = nullptr);

public:
	/// Get a global SliderStyle that lasts for the lifetime of the app.
	/// Can only be called a single thread (generally the main GUI thread).
	static SliderStyle* instance();

	virtual int styleHint (StyleHint hint, const QStyleOption* option = nullptr,
						   const QWidget* widget = nullptr, QStyleHintReturn* returnData = nullptr) const;
};

#endif // SLIDER_STYLE_HPP
